@@ -43,13 +43,19 @@
 #'& Hufthammer (2013) and others. This is simply a wrapper for the
 #'\code{localgauss}-package by Berentsen et.al. (2014).
 #'
+#'A recent option is described by Otneim and Tjøstheim (2019), who allow a full
+#'trivariate fit to a three dimensional data set that is transformed to marginal
+#'standard normality in the context of their test for conditional independence
+#'(see \code{?ci_test} for details), but this can of course be used as an option
+#'to estimate three-variate density functions as well.
+#'
 #'@param x A matrix or data frame with data, on column per variable, one row per
 #'  observation.
 #'@param bw_method The method used for bandwidth selection. Must be either
 #'  \code{"cv"} (cross-validation, slow, but accurate) or \code{"plugin"} (fast,
 #'  but crude).
-#'@param est_method The estimation method, must be either "1par", "5par" or
-#'  "5par_marginals_fixed" (see details).
+#'@param est_method The estimation method, must be either "1par", "5par",
+#'  "5par_marginals_fixed" or "trivariate". (see details).
 #'@param transform_to_marginal_normality Logical, \code{TRUE} if we want to
 #'  transform our data to marginal standard normality. This is assumed by method
 #'  "1par", but can of course be skipped using this argument if it has been done
@@ -122,6 +128,9 @@
 #'the local Gaussian correlation" Statistics and Computing 28, no. 2 (2018):
 #'303-321.
 #'
+#'Otneim, Håkon, and Dag Tjøstheim. "The local Gaussian partial correlation"
+#'Working paper (2019).
+#'
 #'Tjøstheim, D., & Hufthammer, K. O. (2013). Local Gaussian correlation: a new
 #'measure of dependence. Journal of Econometrics, 172(1), 33-48.
 #'
@@ -148,6 +157,12 @@ lg_main <- function(x,
     if((est_method == "1par") & (transform_to_marginal_normality == FALSE)) {
         warning("Estimation method '1par' assumes marginal standard normality.")
     }
+    if((est_method == "trivariate") & (transform_to_marginal_normality == FALSE)) {
+        warning("Estimation method 'trivariate' assumes marginal standard normality.")
+    }
+    if((est_method == "trivariate") & (ncol(x) != 3)) {
+        stop("Data must be trivariate if estimation method is 'trivariate'")
+    }
 
     # Return a list
     ret <- list()
